<?php
/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) 2000-2009 LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

$current_dir = realpath(dirname(__FILE__));
require_once($current_dir . "/../../module/adodb/adodb.inc.php");
require_once('PersistenceManager.php');

/**
 * PersistenceManager のファクトリークラス.
 *
 * データストアへの接続を行い, PersistenceManager のインスタンス生成を管理する.
 *
 * @package XDO
 * @author Kentaro Ohkouchi
 * @version $Id$
 */
class XDO_PersistenceManagerFactory {

    /** ConnectionFactory インスタンス */
    var $connectionFactory;

    /** PersistenceManager インスタンス */
    var $persistenceManager;

    /**
     * DSN を引数にしてインスタンスを生成するコンストラクタ.
     *
     * このクラスのインスタンスを生成すると同時に, データストアへの接続を開始する.
     *
     * @param string $dsn データソース名
     */
    function XDO_PersistenceManagerFactory($dsn = null) {
        $this->__constract($dsn);
    }

    /**
     * DSN を引数にしてインスタンスを生成するコンストラクタ.
     *
     * このクラスのインスタンスを生成すると同時に, データストアへの接続を開始する.
     *
     * @param string $dsn データソース名
     */
    function __construct($dsn = null) {
        // TODO XDO_ConnectionFactory を使用する
        $this->connectionFactory = ADONewConnection($dsn . "?debug");
        $this->connectionFactory->SetFetchMode(ADODB_FETCH_ASSOC);
    }

    /**
     * PersistenceManager インスタンスを取得する.
     *
     * PersistenceManager インスタンスは, シングルトンである.
     *
     * @return XDO_PersistenceManager PersistenceManager インスタンス
     */
    function getPersistenceManager() {
        if ($this->persistenceManager == null) {
            $this->persistenceManager = 
                new XDO_PersistenceManager($this->connectionFactory);
        }
        return $this->persistenceManager;
    }
}
?>