<?php
/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) 2000-2008 LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/**
 * シーケンスを扱うためのクラス.
 *
 * @package XDO
 * @author Kentaro Ohkouchi
 * @version $Id$
 */
class XDO_Sequence {

    /** シーケンス名. */
    var $sequenceName;
    /** ConnectionFactory インスタンス */
    var $connectionFactory;

    /**
     * シーケンス名と, ConnectionFactory を使用して, インスタンスを生成する
     * コンストラクタ.
     *
     * @param string $sequenceName シーケンス名
     * @param ConnectionFactory $connectionFactory ConnectionFactory インスタンス
     */
    function XDO_Sequence($sequenceName, &$connectionFactory) {
        $this->__construct($sequenceName, $connectionFactory);
    }

    /**
     * シーケンス名と, ConnectionFactory を使用して, インスタンスを生成する
     * コンストラクタ.
     *
     * @param string $sequenceName シーケンス名
     * @param ConnectionFactory $connectionFactory ConnectionFactory インスタンス
     */
    function __construct($sequenceName, &$connectionFactory) {
        $this->sequenceName = $sequenceName;
        $this->connectionFactory = $connectionFactory;
    }

    /**
     * 現在のシーケンス値を取得する.
     *
     * @access public
     * @return long 現在のシーケンス値
     */
    function currentValue() {

    }

    /**
     * 次のシーケンス値を取得する.
     *
     * @access public
     * @return long 次のシーケンス値
     */
    function nextValue() {
        return $this->connectionFactory->GenID($this->sequenceName);
    }

    /**
     * シーケンス値を設定する.
     *
     * @access public
     * @return void
     */
    function setValue($value) {
        $this->connectionFactory->GenID($this->sequenceName, $value);
    }
}
?>
