<?php
/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) 2000-2008 LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/**
 * トランザクションを扱うためのクラス.
 *
 * @package XDO
 * @author Kentaro Ohkouchi
 * @version $Id$
 */
class XDO_Transaction {

    /** PersistenceManager インスタンス. */
    var $persistenceManager;

    /**
     * PersistenceManager を使用して, インスタンスを生成する.
     *
     * 同時に, 現在のトランザクションを開始する.
     *
     * @param XDO_PersistenceManager &$persistenceManager
     *                                PersistenceManager インスタンス
     */
    function XDO_Transaction(&$persistenceManager) {
        $this->__construct($persistenceManager);
    }

    /**
     * PersistenceManager を使用して, インスタンスを生成する.
     *
     * 同時に, 現在のトランザクションを開始する.
     *
     * @param XDO_PersistenceManager &$persistenceManager 
     *                                PersistenceManager インスタンス
     */
    function __construct(&$persistenceManager) {
        $this->persistenceManager = $persistenceManager;
        $this->persistenceManager->executeBySql("BEGIN");
    }

    /**
     * 現在のトランザクションを開始する.
     *
     * @access public
     * @return void
     */
    function begin() {
        $this->persistenceManager->executeBySql("BEGIN");
    }

    /**
     * 現在のトランザクションをコミットする.
     *
     * @access public
     * @return void
     */
    function commit() {
        $this->persistenceManager->executeBySql("COMMIT");
    }

    /**
     * 現在のトランザクションのロールバックを行う.
     *
     * @access public
     * @return void
     */
    function rollback() {
        $this->persistenceManager->executeBySql("ROLLBACK");
    }
}
?>
